import { aws_ec2 } from 'aws-cdk-lib';
import type { Construct } from 'constructs';
import type { IBastiInstance } from './basti-instance';
/**
 * The properties for the bastion access security group.
 */
export interface BastiAccessSecurityGroupProps extends aws_ec2.SecurityGroupProps {
    /**
     * Basti ID
     *
     * This ID is used as a suffix for the name, it is not the ID of the basti
     * instance.
     *
     * @default - A 8-character pseudo-random string
     */
    readonly bastiId?: string;
}
/**
 * The security group for the bastion instance.
 */
export declare class BastiAccessSecurityGroup extends aws_ec2.SecurityGroup {
    /**
     * The basti custom ID for the security group.
     */
    readonly bastiId: string;
    /**
     * Constructs a new instance of the BastiAccessSecurityGroup class.
     * @param scope The scope of the construct.
     * @param id The ID of the construct.
     * @param props The properties of the construct.
     */
    constructor(scope: Construct, id: string, props: BastiAccessSecurityGroupProps);
    /**
     * Adds an ingress rule to the security group. That allows the
     * bastion instance to access the target instance.
     *
     * @param bastiInstance The Basti instance
     * @param port The port to allow access to
     */
    allowBastiInstanceConnection(bastiInstance: IBastiInstance, port: aws_ec2.Port): void;
}
